package uk.sky.bob.application

import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.material.Button
import androidx.compose.material.ExperimentalMaterialApi
import androidx.compose.material.FilterChip
import androidx.compose.material.MaterialTheme
import androidx.compose.material.Text
import androidx.compose.material.TextField
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.saveable.rememberSaveable
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.text.input.TextFieldValue
import androidx.compose.ui.unit.dp
import org.jetbrains.compose.ui.tooling.preview.Preview

@OptIn(ExperimentalMaterialApi::class)
@Composable
@Preview
fun App() {
    MaterialTheme {
        Column(Modifier.fillMaxWidth(), horizontalAlignment = Alignment.CenterHorizontally) {
            Row {
                val state = remember { mutableStateOf(Sentiment.HAPPY) }
                for (emotion in Sentiment.entries) {
                    FilterChip(
                        onClick = { state.value = emotion },
                        selected = state.value == emotion,
                        modifier = Modifier.padding(8.dp),
                        leadingIcon = { Text(emotion.leadingIcon) },
                    ) {
                        Text(emotion.friendlyName)
                    }
                }
            }

            Row {
                var text by rememberSaveable(stateSaver = TextFieldValue.Saver) {
                    mutableStateOf(
                        TextFieldValue("")
                    )
                }
                TextField(
                    value = text,
                    onValueChange = { text = it },
                    label = { Text("Your comment") },
                    maxLines = 3,
                )
            }

            Row {
                Button(onClick = { /* Handle submit */ }) {
                    Text("Submit")
                }
            }
        }
    }
}

